============
Installation
============

At the command line::

    $ pip install kolla-kubernetes

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv kolla-kubernetes
    $ pip install kolla-kubernetes
